@@ -4,6 +4,7 @@
 #![deny(rust_2018_compatibility)]
 #![deny(rust_2018_idioms)]
 #![deny(warnings)]
+#![allow(deprecated)]
 #![allow(clippy::multiple_crate_versions)]
 #![allow(clippy::missing_errors_doc)]
 #![allow(clippy::missing_const_for_fn)]
@@ -15,9 +16,9 @@ pub mod ser;
 pub use serde;
 
 #[doc(inline)]
-pub use self::de::{from_slice, from_str, CharVec};
+pub use self::de::{from_slice, from_str};
 #[doc(inline)]
-pub use self::ser::{to_string, to_vec, Bytes, SerializeOptions};
+pub use self::ser::{to_string, to_vec, SerializeOptions};
 
 #[allow(clippy::uninit_assumed_init)]
 unsafe fn uninitialized<T>() -> T {
